@@ -7,9 +7,6 @@ from json import dumps
 import logging
 from helpers.logs import create_logger
 
-# logging.basicConfig(level=logging.INFO,
-#                     format='%(asctime)s - %(name)s - %(funcName)s - %(levelname)s - %(threadName)s - %(message)s')
-#logger = logging.getLogger(__name__)
 logger = create_logger(__name__)
 
 
@@ -25,7 +22,7 @@ def calc_execution_time(func):
             res = func(*args, **kwargs)
             after = default_timer()
             execution_time = after - before
-            print(f"execution time of the Function {func.__qualname__} is :=> {execution_time} seconds")
+            print("execution time of the Function {} is :=> {} seconds".format(func.__qualname__, execution_time))
             return res
 
         return wrapper
@@ -50,13 +47,13 @@ class BRabbit:
         self.connection = rabbitpy.Connection('amqp://' + host + ':' + str(port))
 
     def close_connection(self):
-        # self._shutdown_gracefully()
+        self._shutdown_gracefully()
         self.connection.close()
 
     def add_active_queues(self, queue):
         self._active_queues.append(queue)
 
-    #@calc_execution_time
+    # @calc_execution_time
     def _shutdown_gracefully(self):
 
         for activeQueue in self._active_queues:
@@ -89,12 +86,12 @@ class BRabbit:
                                                       exchange_type=exchange_type,
                                                       durable=True)
                     self.exchange.declare()
-                    logger.info(f'Exchange is declared with the name: {self.exchange_name}')
+                    logger.info('Exchange is declared with the name: {}'.format(self.exchange_name))
 
             except Exception as e:
                 logger.exception(e)
 
-        @calc_execution_time
+        # @calc_execution_time
         def publish(self, routing_key: str, payload: str, important: bool = True):
             """
 				Publish of internal event. All internal subscribers will receive it.
@@ -115,18 +112,18 @@ class BRabbit:
                     if not published:
 
                         logger.warning(
-                            f'message sent from: {self.exchange_name} but RabbitMQ indicates Message publishing failure')
+                            'message sent from: {} but RabbitMQ indicates Message publishing failure'.format(self.exchange_name))
                     else:
 
-                        logger.info(f'message sent from: {self.exchange_name} and received successfully from RabbitMQ')
+                        logger.info('message sent from: {} and received successfully from RabbitMQ'.format(self.exchange_name))
                 return published
 
             except rabbitpy.exceptions.MessageReturnedException as e:
                 logger.error(
-                    f"Because of the Mandatory Publishing, a Consumer Queue must already be binded to the Exchange"
-                    f" to make sure that the published message will be sooner or later consumed and we will not lose it"
-                    f" so make sure that the subscriber Queue is already bounded to the Publisher  \n"
-                    f"More Description of the Exception => {e.args}")
+                    "Because of the Mandatory Publishing, a Consumer Queue must already be binded to the Exchange"
+                    " to make sure that the published message will be sooner or later consumed and we will not lose it"
+                    " so make sure that the subscriber Queue is already bounded to the Publisher  \n"
+                    "More Description of the Exception => {}".format(e.args))
 
             except Exception as e:
                 logger.exception(e.args, exc_info=False)
@@ -136,7 +133,7 @@ class BRabbit:
 		Subscribe to events send by publisher
 		"""
 
-        #@calc_execution_time
+        # @calc_execution_time
         def __init__(self, b_rabbit, routing_key: str,
                      publisher_name: str, exchange_type: str = 'topic',
                      external: bool = False, important_subscription: bool = True, event_listener: Callable = None):
@@ -164,11 +161,11 @@ class BRabbit:
                                                   durable=True)
                 self.exchange.declare()
                 logger.info(
-                    f'Exchange is declared Successfully from Subscriber: {__name__} | with the name: {self.exchange_name}')
+                    'Exchange is declared Successfully from Subscriber: {} | with the name: {}'.format(__name__,self.exchange_name))
 
                 subscriber_name = self.exchange_name + '_' + routing_key + '_' + self.__get_subscriber_name() + '_queue'
 
-                logger.info(f'subscriber name: {subscriber_name}')
+                logger.info('subscriber name: {}'.format(subscriber_name))
                 queue = rabbitpy.Queue(channel,
                                        name=subscriber_name,
                                        durable=important_subscription,
@@ -176,12 +173,11 @@ class BRabbit:
                                        exclusive=False)
                 queue.declare()
 
-                logger.info(f'{queue.name} was successfully declared from subscriber: {subscriber_name}')
+                # logger.info('{queue.name} was successfully declared from subscriber: {subscriber_name}')
                 queue.bind(self.exchange_name, routing_key)
                 self.queue_name = queue.name
                 self.event_listener = event_listener
 
-        #@calc_execution_time
         def __subscribe(self):
             '''
 				start waiting on events. You may do this in parallel.
@@ -200,8 +196,8 @@ class BRabbit:
 
             subscriber_thread = threading.Thread(target=self.__subscribe, *thread_args, **thread_kwargs)
             subscriber_thread.start()
-            if subscriber_thread.isAlive():
-                logger.info(f"Subscriber is running on The Thread: {subscriber_thread.name}")
+            if subscriber_thread.is_alive():
+                logger.info("Subscriber is running on The Thread: {}".format(subscriber_thread.name))
 
         def __get_subscriber_name(self, in_docker=True):
             """get the subscriber name from host"""
@@ -209,12 +205,12 @@ class BRabbit:
                 if not in_docker:
                     import os
                     name = os.path.dirname(os.path.abspath(__file__))  # get the whole Path of the Project Repository
-                    logger.debug(f'name of the current Subscriber: {name}')
+                    # logger.debug(f'name of the current Subscriber: {name}')
                     return name.split('\\')[-2]  # return only the name of the Project (example: Statistics Service)
                 else:
                     import socket
                     name = socket.gethostname()
-                    logger.debug(f'name of the current Subscriber: {name}')
+                    # logger.debug(f'name of the current Subscriber: {name}')
                     return name
             except Exception as e:
                 logger.exception(e)
@@ -255,9 +251,17 @@ class BRabbit:
             self.b_rabbit, self.task_listener = b_rabbit, task_listener
             self.executor_name, self.exchange_name = executor_name, self.exchange_name
 
-            with b_rabbit.connection.channel() as channel:
+        def __enter__(self):
+            with self.b_rabbit.connection.channel() as channel:
                 exchange = rabbitpy.DirectExchange(channel=channel, name=self.exchange_name, durable=True)
                 exchange.declare()
+            return self
+
+        def __exit__(self, exc_type, exc_val, exc_tb):
+            try:
+                self.b_rabbit.close_connection()
+            except:
+                pass
 
         def __register_on_task(self, queue_name=''):
             """
@@ -287,7 +291,7 @@ class BRabbit:
                         logger.critical('Error in Custom Implementation of TaskExecuter')
                         logger.exception(e.args, exc_info=False)
 
-        @calc_execution_time
+        # @calc_execution_time
         def send_return(self, payload: str):
             """
 				Send return to TaskRequester which contains the results of task.
@@ -301,14 +305,13 @@ class BRabbit:
 
             response.publish(exchange='', routing_key=self.replyTo)
 
-        @calc_execution_time
         def run_task_on_thread(self, *thread_args, **thread_kwargs):
             """start task Executor on an independent Thread"""
 
             task_thread = threading.Thread(target=self.__register_on_task, *thread_args, **thread_kwargs)
             task_thread.start()
-            if task_thread.isAlive():
-                logger.info(f"Task Executor is running on The Thread: {task_thread.name}")
+            if task_thread.is_alive():
+                logger.info("Task Executor is running on The Thread: {}".format(task_thread.name))
 
     class TaskRequesterSynchron:
         '''
@@ -340,10 +343,9 @@ class BRabbit:
                                                         durable=True)
 
                 self.exchange.declare()
-                logger.info(
-                    f'Exchange: {self.exchange_name} was successfully declared from task Requester: {executor_name} ')
+                # logger.info(
+                #     f'Exchange: {self.exchange_name} was successfully declared from task Requester: {executor_name} ')
 
-        @calc_execution_time
         def request_task(self, payload: str, queue_name=''):
             """
 				Do request task from executer.
@@ -357,8 +359,8 @@ class BRabbit:
 
                 callback_queue = rabbitpy.Queue(channel, name=queue_name, durable=True, exclusive=True)
                 callback_queue.declare()
-                logger.info(
-                    f'{callback_queue.name} was successfully declared from task Requester: {self.executor_name}')
+                # logger.info(
+                #     f'{callback_queue.name} was successfully declared from task Requester: {self.executor_name}')
 
                 request = rabbitpy.Message(channel,
                                            body_value=payload,
@@ -371,8 +373,8 @@ class BRabbit:
                 for message in callback_queue.consume(prefetch=1):
                     message.ack()
 
-                    if self.corr_id == message.properties[
-                        'correlation_id']:  # check if correlation id fits to the call you did
+                    # check if correlation id fits to the call you did
+                    if self.corr_id == message.properties['correlation_id']:
                         self.response_listener(message.body)
                     return True
 
